# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cve.proto

import sys

_b = sys.version_info[0] < 3 and (lambda x: x) or (lambda x: x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor.FileDescriptor(
    name='cve.proto',
    package='',
    syntax='proto2',
    serialized_options=None,
    serialized_pb=_b(
        '\n\tcve.proto\"G\n\treference\x12\x0b\n\x03url\x18\x01 \x02(\t\x12\x0c\n\x04name\x18\x02 \x02(\t\x12\x11\n\trefsource\x18\x03 \x02(\t\x12\x0c\n\x04tags\x18\x04 \x03(\t\"W\n\rversion_match\x12\r\n\x05start\x18\x01 \x02(\t\x12\x15\n\rstart_include\x18\x02 \x02(\x08\x12\x0b\n\x03\x65nd\x18\x03 \x02(\t\x12\x13\n\x0b\x65nd_include\x18\x04 \x02(\x08\"\xdd\x01\n\tcpe_match\x12\x0c\n\x04part\x18\x01 \x02(\t\x12\x0e\n\x06vendor\x18\x02 \x01(\t\x12\x0f\n\x07product\x18\x03 \x01(\t\x12\x1f\n\x07version\x18\x04 \x01(\x0b\x32\x0e.version_match\x12\x0e\n\x06update\x18\x05 \x01(\t\x12\x0f\n\x07\x65\x64ition\x18\x06 \x01(\t\x12\x10\n\x08language\x18\x07 \x01(\t\x12\x12\n\nsw_edition\x18\x08 \x01(\t\x12\n\n\x02sw\x18\t \x01(\t\x12\n\n\x02hw\x18\n \x01(\t\x12\r\n\x05other\x18\x0b \x01(\t\x12\x12\n\nvulnerable\x18\x0c \x02(\x08\")\n\x06target\x12\x1f\n\x0b\x63pe_matches\x18\x01 \x03(\x0b\x32\n.cpe_match\"\xe1\x01\n\x03\x63ve\x12\x0f\n\x07scan_id\x18\x01 \x02(\x05\x12\x0e\n\x06\x63ve_id\x18\x02 \x02(\t\x12\x18\n\x07targets\x18\x03 \x03(\x0b\x32\x07.target\x12\x0b\n\x03\x63we\x18\x04 \x01(\x05\x12\x13\n\x0b\x64\x65scription\x18\x05 \x02(\t\x12\x1e\n\nreferences\x18\x06 \x03(\x0b\x32\n.reference\x12\x16\n\x0e\x63vss_v3_vector\x18\x07 \x01(\t\x12\x16\n\x0e\x63vss_v2_vector\x18\x08 \x01(\t\x12\x16\n\x0epublished_date\x18\t \x02(\t\x12\x15\n\rmodified_date\x18\x13 \x02(\t')
)

_REFERENCE = _descriptor.Descriptor(
    name='reference',
    full_name='reference',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='url', full_name='reference.url', index=0,
            number=1, type=9, cpp_type=9, label=2,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='name', full_name='reference.name', index=1,
            number=2, type=9, cpp_type=9, label=2,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='refsource', full_name='reference.refsource', index=2,
            number=3, type=9, cpp_type=9, label=2,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='tags', full_name='reference.tags', index=3,
            number=4, type=9, cpp_type=9, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto2',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=13,
    serialized_end=84,
)

_VERSION_MATCH = _descriptor.Descriptor(
    name='version_match',
    full_name='version_match',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='start', full_name='version_match.start', index=0,
            number=1, type=9, cpp_type=9, label=2,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='start_include', full_name='version_match.start_include', index=1,
            number=2, type=8, cpp_type=7, label=2,
            has_default_value=False, default_value=False,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='end', full_name='version_match.end', index=2,
            number=3, type=9, cpp_type=9, label=2,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='end_include', full_name='version_match.end_include', index=3,
            number=4, type=8, cpp_type=7, label=2,
            has_default_value=False, default_value=False,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto2',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=86,
    serialized_end=173,
)

_CPE_MATCH = _descriptor.Descriptor(
    name='cpe_match',
    full_name='cpe_match',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='part', full_name='cpe_match.part', index=0,
            number=1, type=9, cpp_type=9, label=2,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='vendor', full_name='cpe_match.vendor', index=1,
            number=2, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='product', full_name='cpe_match.product', index=2,
            number=3, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='version', full_name='cpe_match.version', index=3,
            number=4, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='update', full_name='cpe_match.update', index=4,
            number=5, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='edition', full_name='cpe_match.edition', index=5,
            number=6, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='language', full_name='cpe_match.language', index=6,
            number=7, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='sw_edition', full_name='cpe_match.sw_edition', index=7,
            number=8, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='sw', full_name='cpe_match.sw', index=8,
            number=9, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='hw', full_name='cpe_match.hw', index=9,
            number=10, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='other', full_name='cpe_match.other', index=10,
            number=11, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='vulnerable', full_name='cpe_match.vulnerable', index=11,
            number=12, type=8, cpp_type=7, label=2,
            has_default_value=False, default_value=False,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto2',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=176,
    serialized_end=397,
)

_TARGET = _descriptor.Descriptor(
    name='target',
    full_name='target',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='cpe_matches', full_name='target.cpe_matches', index=0,
            number=1, type=11, cpp_type=10, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto2',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=399,
    serialized_end=440,
)

_CVE = _descriptor.Descriptor(
    name='cve',
    full_name='cve',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='scan_id', full_name='cve.scan_id', index=0,
            number=1, type=5, cpp_type=1, label=2,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='cve_id', full_name='cve.cve_id', index=1,
            number=2, type=9, cpp_type=9, label=2,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='targets', full_name='cve.targets', index=2,
            number=3, type=11, cpp_type=10, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='cwe', full_name='cve.cwe', index=3,
            number=4, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='description', full_name='cve.description', index=4,
            number=5, type=9, cpp_type=9, label=2,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='references', full_name='cve.references', index=5,
            number=6, type=11, cpp_type=10, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='cvss_v3_vector', full_name='cve.cvss_v3_vector', index=6,
            number=7, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='cvss_v2_vector', full_name='cve.cvss_v2_vector', index=7,
            number=8, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='published_date', full_name='cve.published_date', index=8,
            number=9, type=9, cpp_type=9, label=2,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='modified_date', full_name='cve.modified_date', index=9,
            number=19, type=9, cpp_type=9, label=2,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto2',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=443,
    serialized_end=668,
)

_CPE_MATCH.fields_by_name['version'].message_type = _VERSION_MATCH
_TARGET.fields_by_name['cpe_matches'].message_type = _CPE_MATCH
_CVE.fields_by_name['targets'].message_type = _TARGET
_CVE.fields_by_name['references'].message_type = _REFERENCE
DESCRIPTOR.message_types_by_name['reference'] = _REFERENCE
DESCRIPTOR.message_types_by_name['version_match'] = _VERSION_MATCH
DESCRIPTOR.message_types_by_name['cpe_match'] = _CPE_MATCH
DESCRIPTOR.message_types_by_name['target'] = _TARGET
DESCRIPTOR.message_types_by_name['cve'] = _CVE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

reference = _reflection.GeneratedProtocolMessageType('reference', (_message.Message,), dict(
    DESCRIPTOR=_REFERENCE,
    __module__='cve_pb2'
    # @@protoc_insertion_point(class_scope:reference)
))
_sym_db.RegisterMessage(reference)

version_match = _reflection.GeneratedProtocolMessageType('version_match', (_message.Message,), dict(
    DESCRIPTOR=_VERSION_MATCH,
    __module__='cve_pb2'
    # @@protoc_insertion_point(class_scope:version_match)
))
_sym_db.RegisterMessage(version_match)

cpe_match = _reflection.GeneratedProtocolMessageType('cpe_match', (_message.Message,), dict(
    DESCRIPTOR=_CPE_MATCH,
    __module__='cve_pb2'
    # @@protoc_insertion_point(class_scope:cpe_match)
))
_sym_db.RegisterMessage(cpe_match)

target = _reflection.GeneratedProtocolMessageType('target', (_message.Message,), dict(
    DESCRIPTOR=_TARGET,
    __module__='cve_pb2'
    # @@protoc_insertion_point(class_scope:target)
))
_sym_db.RegisterMessage(target)

cve = _reflection.GeneratedProtocolMessageType('cve', (_message.Message,), dict(
    DESCRIPTOR=_CVE,
    __module__='cve_pb2'
    # @@protoc_insertion_point(class_scope:cve)
))
_sym_db.RegisterMessage(cve)

# @@protoc_insertion_point(module_scope)
