# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: coverage.proto

import sys

_b = sys.version_info[0] < 3 and (lambda x: x) or (lambda x: x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor.FileDescriptor(
    name='coverage.proto',
    package='',
    syntax='proto2',
    serialized_options=None,
    serialized_pb=_b(
        '\n\x0e\x63overage.proto\"8\n\x10payload_validity\x12\x12\n\npayload_id\x18\x01 \x01(\x05\x12\x10\n\x08validity\x18\x02 \x02(\x08\"\x92\x01\n\x08\x63overage\x12\x0f\n\x07scan_id\x18\x01 \x02(\x05\x12\x15\n\rmodel_version\x18\x02 \x02(\x05\x12\x34\n\x19previous_payload_validity\x18\x03 \x03(\x0b\x32\x11.payload_validity\x12\x10\n\x08test_ids\x18\x04 \x03(\x05\x12\x16\n\x0eparent_node_id\x18\x05 \x01(\x05')
)

_PAYLOAD_VALIDITY = _descriptor.Descriptor(
    name='payload_validity',
    full_name='payload_validity',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='payload_id', full_name='payload_validity.payload_id', index=0,
            number=1, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='validity', full_name='payload_validity.validity', index=1,
            number=2, type=8, cpp_type=7, label=2,
            has_default_value=False, default_value=False,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto2',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=18,
    serialized_end=74,
)

_COVERAGE = _descriptor.Descriptor(
    name='coverage',
    full_name='coverage',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='scan_id', full_name='coverage.scan_id', index=0,
            number=1, type=5, cpp_type=1, label=2,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='model_version', full_name='coverage.model_version', index=1,
            number=2, type=5, cpp_type=1, label=2,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='previous_payload_validity', full_name='coverage.previous_payload_validity', index=2,
            number=3, type=11, cpp_type=10, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='test_ids', full_name='coverage.test_ids', index=3,
            number=4, type=5, cpp_type=1, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='parent_node_id', full_name='coverage.parent_node_id', index=4,
            number=5, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto2',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=77,
    serialized_end=223,
)

_COVERAGE.fields_by_name['previous_payload_validity'].message_type = _PAYLOAD_VALIDITY
DESCRIPTOR.message_types_by_name['payload_validity'] = _PAYLOAD_VALIDITY
DESCRIPTOR.message_types_by_name['coverage'] = _COVERAGE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

payload_validity = _reflection.GeneratedProtocolMessageType('payload_validity', (_message.Message,), dict(
    DESCRIPTOR=_PAYLOAD_VALIDITY,
    __module__='coverage_pb2'
    # @@protoc_insertion_point(class_scope:payload_validity)
))
_sym_db.RegisterMessage(payload_validity)

coverage = _reflection.GeneratedProtocolMessageType('coverage', (_message.Message,), dict(
    DESCRIPTOR=_COVERAGE,
    __module__='coverage_pb2'
    # @@protoc_insertion_point(class_scope:coverage)
))
_sym_db.RegisterMessage(coverage)

# @@protoc_insertion_point(module_scope)
